==> jruby_1.7.26.orig.tar.gz: jruby-1.7.26/core/src/main/java/org/jruby/util/UriLikePathHelper.java <==
/*
 **** BEGIN LICENSE BLOCK *****
 * Version: EPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Eclipse Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/epl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the EPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the EPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.util;

import java.net.URL;

public class UriLikePathHelper {
    
    private final ClassLoader classLoader;

    public UriLikePathHelper(ClassLoader classLoader) {
        this.classLoader = classLoader;
    }
    
    public URL getResource(String ref) {
        URL url = classLoader.getResource( ref );
        if ( url == null && ref.startsWith( "/" ) ) {
            url = classLoader.getResource( ref.substring( 1 ) );
        }
        return url;
    }
    
    public String getUriLikePath() {
        return createUri("/.jrubydir");
    }

    public String getUriLikePath(String ref) {
        return createUri(ref);
    }
    
    String createUri(String ref) {
        URL url = getResource( ref );
        if ( url == null ) {
            throw new RuntimeException( "reference " + ref + " not found on classloader " + classLoader );
        }
        return "uri:" + url.toString().replaceFirst( ref + "$", "" );
    }
}

==> jruby_9.1.13.0.orig.tar.gz: jruby-9.1.13.0/core/src/main/java/org/jruby/util/UriLikePathHelper.java <==
/*
 **** BEGIN LICENSE BLOCK *****
 * Version: EPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Eclipse Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/epl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the EPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the EPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.util;

import java.net.URL;

public class UriLikePathHelper {
    
    private final Loader loader;

    public UriLikePathHelper(Loader loader) {
        this.loader = loader;
    }

    public URL getResource(String ref) {
        URL url = get( ref );
        if ( url == null && ref.startsWith( "/" ) ) {
            url = get( ref.substring( 1 ) );
        }
        return url;
    }

    private URL get(String ref) {
        return loader.getResource(ref);
    }

    public String getUriLikePath() {
        return createUri("/.jrubydir");
    }

    public String getUriLikeGemPath() {
        return createUri("/specifications/.jrubydir");
    }

    private String createUri(String ref) {
        URL url = getResource( ref );
        if ( url == null ) {
            return null;
        }
        return "uri:" + url.toString().replaceFirst( ref + "$", "" );
    }
}
